//---------------------------------------------------------------------------------
// File Name: DemoPhysicsRender.cpp
// Description: 	
//
// Copyright (C) 2004 - 2005 True Axis Pty Ltd, Australia. 
// All Rights Reserved.
//
// Use of this code is covered by the "TRUE AXIS PHYSICS SDK DEMOS SOURCE LICENSE AGREEMENT".
// Details of this agreement are found in the file "TrueAxisPhysicsSDKDemosSourceLicence.txt".
// You have permission to modify this file and use it for any purpose under the terms of
// the agreement.
//
// History:
//		Created File.
//---------------------------------------------------------------------------------

#include "DemoPhysicsRender.h"

#include "../Interface/IApp.h"
#include "../TA/Common/Vector.h"
#include "../TA/Physics/PhysicsRender.h"

using namespace TA;

namespace DemoPhysicsRender
{
	static IApp* s_pApp = 0;

	//---------------------------------------------------------------------------------
	//---------------------------------------------------------------------------------
	static void TAC_CALL RenderLine(const Vec3& v3PosA, const Vec3& v3PosB, u32 nColour);
	static void TAC_CALL RenderArrow(const Vec3& v3Pos,	const Vec3& v3Vector, u32 nColour);
	static void TAC_CALL RenderPolygon(int nNumVertices, const Vec3* pv3VertexList, const Vec3* pv3NormalList);

	//---------------------------------------------------------------------------------
	//---------------------------------------------------------------------------------
	void Initialise(IApp* pApp)
	{	
		s_pApp = pApp;
		PhysicsRender::SetRenderLineCallback(RenderLine);
		PhysicsRender::SetRenderArrowCallback(RenderArrow);
		PhysicsRender::SetRenderPolygonCallback(RenderPolygon);
	}

	//---------------------------------------------------------------------------------
	//---------------------------------------------------------------------------------
	void Finalise()
	{
		s_pApp = 0;
		PhysicsRender::SetRenderLineCallback(0);
		PhysicsRender::SetRenderArrowCallback(0);
		PhysicsRender::SetRenderPolygonCallback(0);
	}
	
	//---------------------------------------------------------------------------------
	//---------------------------------------------------------------------------------
	static void TAC_CALL RenderLine(
		const Vec3& v3PosA, 
		const Vec3& v3PosB,
		u32 nColour)
	{
		s_pApp->RenderLine(v3PosA, v3PosB, nColour);
	}

	//---------------------------------------------------------------------------------
	//---------------------------------------------------------------------------------
	static void TAC_CALL RenderArrow(
		const Vec3& v3Pos, 
		const Vec3& v3Vector,
		u32 nColour)
	{
		s_pApp->RenderLine(v3Pos, v3Pos + v3Vector, nColour);
	}

	//---------------------------------------------------------------------------------
	//---------------------------------------------------------------------------------	
	static void TAC_CALL RenderPolygon(
		int nNumVertices,
		const Vec3* pv3VertexList, 
		const Vec3* pv3NormalList)
	{
		s_pApp->RenderPolygon(nNumVertices, pv3VertexList, pv3NormalList);
	}

}
