//---------------------------------------------------------------------------------
// File Name: HeightField.h
// Description:
//
// Copyright (C) 2002 True Axis Pty Ltd, Australia. 
// All Rights Reserved.
//
// Use of this code is covered by the "TRUE AXIS PHYSICS SDK DEMOS SOURCE LICENSE AGREEMENT".
// Details of this agreement are found in the file "TrueAxisPhysicsSDKDemosSourceLicence.txt".
// You have permission to modify this file and use it for any purpose under the terms of
// the agreement.
//
// History:
//		Created File.
//---------------------------------------------------------------------------------

#ifndef TA_HEIGHTFIELD_H
#define TA_HEIGHTFIELD_H

#ifndef TA_DEBUG_H
#include "../TA/Common/Debug.h"
#endif // TA_DEBUG_H

class HeightField
{
public:
	HeightField();
	~HeightField();

	void Initialise(
		int nLevelsX, 
		int nLevelsY, 
		float fFractalDimension, 
		int nSeed, 
		float fHorizontalScale,
		float fVerticalScale,
		int nSmoothAmount = 4,
		int nQuatize = 0);	
	void Initialise(
		float* pfData,
		int nWidth, 
		int nHeight,
		float fHorizontalScale,
		float fVerticalScale);	
	void Finalise();

	inline float GetHeightAt(int nY, int nX) const { return HeightFeild(nY, nX); }
	int GetSizeX() const { return m_nSizeX; }
	int GetSizeY() const { return m_nSizeY; }

	float GetHorizontalScale() { return m_fHorizontalScale; }
	float GetVerticalScale() { return m_fVerticalScale; }
 
private:

	inline float& HeightFeild(int nY, int nX) 
	{ 
		TA_ASSERT(nY >= 0);
		TA_ASSERT(nY < m_nSizeY);
		TA_ASSERT(nX >= 0);
		TA_ASSERT(nX < m_nSizeX);
		return m_pfHeightData[m_nSizeX * nY + nX]; 
	}
	inline const float& HeightFeild(int nY, int nX) const
	{ 
		TA_ASSERT(nY >= 0);
		TA_ASSERT(nY < m_nSizeY);
		TA_ASSERT(nX >= 0);
		TA_ASSERT(nX < m_nSizeX);
		return m_pfHeightData[m_nSizeX * nY + nX]; 
	}
	inline float Guassian();
	void DoGenerateLandscape(int levels, int nLevel, float fFractalDimension);

	float* m_pfHeightData;
	int m_nSizeX;
	int m_nSizeY;
	float m_fHorizontalScale;
	float m_fVerticalScale;
};

#endif // TA_HEIGHTFIELD_H

